@@ -1,7 +1,7 @@
 package WordList;
 
 our $DATE = '2018-04-02'; # DATE
-our $VERSION = '0.3.2'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -109,7 +109,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.3.2 of WordList (from Perl distribution WordList), released on 2018-04-02.
+This document describes version 0.4.0 of WordList (from Perl distribution WordList), released on 2018-04-02.
 
 =head1 SYNOPSIS
 
@@ -127,11 +127,12 @@ are read-only/immutable and the modules are designed to have low startup
 overhead. This makes them more suitable for use in CLI scripts which often only
 want to pick a word from one or several lists.
 
-Words (or phrases) must be put in C<__DATA__> section, one per line. Putting the
-wordlist in the C<__DATA__> section relieves perl from having to parse the list
-during the loading of the module. To search for words or picking some random
-words from the list, the module also need not slurp the whole list into memory
-(and will not do so unless explicitly instructed).
+Unless you are defining a dynamic wordlist (see below), words (or phrases) must
+be put in C<__DATA__> section, one per line. Putting the wordlist in the
+C<__DATA__> section relieves perl from having to parse the list during the
+loading of the module. To search for words or picking some random words from the
+list, the module also need not slurp the whole list into memory (and will not do
+so unless explicitly instructed).
 
 You must sort your words ascibetically (or by Unicode code point). Sorting makes
 it more convenient to diff different versions of the module, as well as
@@ -141,6 +142,12 @@ C<frequency>).
 
 There must not be any duplicate entry in the word list.
 
+B<Dynamic wordlist.> A dynamic wordlist must set package variable C<$DYNAMIC> to
+true. A dynamic wordlist does not put the wordlist in the DATA section; instead,
+user relies on C<each_word()> or C<all_words()> to get the list.
+
+=head1 DIFFERENCES WITH GAMES::WORD::WORDLIST
+
 Since this is a new and non-backward compatible interface from
 Games::Word::Wordlist, I also make some other changes:
 
