@@ -1,12 +1,12 @@
 package WordList::Test::OneTwo;
 
 our $DATE = '2018-04-02'; # DATE
-our $VERSION = '0.3.2'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_nonword_chars",0,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"shortest_word_len",3,"avg_word_len",3,"longest_word_len",3,"num_words",2); # STATS
+our %STATS = ("longest_word_len",3,"avg_word_len",3,"num_words",2,"shortest_word_len",3,"num_words_contains_nonword_chars",0,"num_words_contains_unicode",0,"num_words_contains_whitespace",0); # STATS
 
 1;
 # ABSTRACT: Wordlist that contains "one" and "two"
@@ -21,7 +21,7 @@ WordList::Test::OneTwo - Wordlist that contains "one" and "two"
 
 =head1 VERSION
 
-This document describes version 0.3.2 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2018-04-02.
+This document describes version 0.4.0 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2018-04-02.
 
 =head1 SYNOPSIS
 
